@@ -103,6 +103,13 @@ class ConfigureCmd(Command):
         }
         if(my_meter["type"] == "contact"):
             capture_config['Arguments']['ip-address'] = my_meter["ip_address"]
+            capture_config['Arguments']['daq-type'] = my_meter["daq_type"]
+            if(my_meter['daq_type'] == "nerdjack"):
+                if(my_meter["sensors"]["filter"]["keep"] == True):
+                    capture_config['Arguments']['filter-index'] = "%i"%my_meter["sensors"]["filter"]["filter_index"]
+                else:
+                    capture_config['Arguments']['filter-index'] = None
+            
         else:
             capture_config['Arguments']['tty'] = my_meter["tty"]
 
@@ -110,7 +117,7 @@ class ConfigureCmd(Command):
         capture_config['Outputs'] = {"output": sensor_path}
         path = os.path.join(self.module_dir, "%s_capture.conf" % my_meter['name'])
         try:
-            with open(path, 'w') as configfile:
+            with open(path, 'w') as configfile: 
                 capture_config.write(configfile)
         except PermissionError:
             self.run_as_root()
@@ -170,7 +177,14 @@ class ConfigureCmd(Command):
         if(my_meter['type'] == "noncontact"):
             num_channels = 8
         else:  # contact
-            num_channels = 6
+            if(my_meter['daq_type'] == "labjack"):
+                num_channels = 6
+            if(my_meter['daq_type'] == "nerdjack"):
+                if(my_meter["sensors"]["filter"]["keep"] == True):
+                    num_channels = 7
+                else:
+                    num_channels = 6
+
         for i in range(1, num_channels + 1):
             sensor_config['Element%d' % i] = {"name": "Ch%i" % i,
                                               "units": "ADC"}
@@ -301,4 +315,4 @@ class ConfigureCmd(Command):
         
     def run_as_root(self):
         print("["+COL_RED+"ERROR"+COL_RESET+"]\n run as [sudo nilm configure]")
-        exit(1)
+        exit(1)
\ No newline at end of file
