@@ -93,7 +93,13 @@ class ScopeCmd(Command):
 
         # pipes to receive data
         if my_meter['type'] == 'contact':
-            npipe = LocalPipe("uint16_6", name="raw")
+            if(my_meter['daq_type'] == "labjack"):
+                npipe = LocalPipe("uint16_6", name="raw")
+            elif(my_meter['daq_type'] == "nerdjack"):
+                if(my_meter['sensors']['filter']["keep"] == True):
+                    npipe = LocalPipe("uint16_7", name="raw")
+                else:
+                    npipe = LocalPipe("uint16_6", name="raw")
         else:
             npipe = LocalPipe("int16_8", name="raw")
 
@@ -108,6 +114,13 @@ class ScopeCmd(Command):
             config["tty"] = my_meter["tty"]
         else:
             config["ip_address"] = my_meter["ip_address"]
+            config["daq_type"] = my_meter["daq_type"]
+            if(my_meter['daq_type'] == "nerdjack"):
+                if(my_meter['sensors']['filter']["keep"] == True):
+                    config['filter_index'] = my_meter["sensors"]["filter"]["filter_index"]
+                else:
+                    config['filter_index'] = None
+                print(config['filter_index'])
         capture_args = argparse.Namespace(**config)
         self.my_capture = capture.Capture()
 
@@ -214,13 +227,34 @@ class ScopeCmd(Command):
             ax.set_title(
                 "Raw data from contact meter [%s]" % my_meter["ip_address"])
             for idx in channels:
-                if idx < 0 or idx > 5:
-                    print("Error, invalid channel: %d" % idx)
-                    exit(1)
-                if idx < 3:
-                    role = "[%d] Current" % idx
+                if(my_meter['daq_type'] == "nerdjack"):
+                    if(my_meter["sensors"]["filter"]["keep"] == True):
+                        if idx < 0 or idx > 6:
+                            print("Error, invalid channel: %d" % idx)
+                            exit(1)
+                        if idx < 3:
+                            role = "[%d] Current" % idx
+                        if idx >= 3 and idx < 6:
+                            role = "[%d] Voltage" % idx
+                        else:
+                            role = "[%d] Filter" % idx
+                    else:
+                        if idx < 0 or idx > 5:
+                            print("Error, invalid channel: %d" % idx)
+                            exit(1)
+                        if idx < 3:
+                            role = "[%d] Current" % idx
+                        else:
+                            role = "[%d] Voltage" % idx
                 else:
-                    role = "[%d] Voltage" % idx
+                    if idx < 0 or idx > 5:
+                        print("Error, invalid channel: %d" % idx)
+                        exit(1)
+                    if idx < 3:
+                        role = "[%d] Current" % idx
+                    else:
+                        role = "[%d] Voltage" % idx
+
                 data = np.zeros(self.plot_width)
                 points, = ax.plot(
                     list(range(self.plot_width)), data, label=role)
