@@ -2,11 +2,12 @@ import numpy as np
 import sys
 import asyncio
 import json
-from joule.utils.time import (timestamp_to_human,
+from joule.models.pipes import EmptyPipe
+from joule.utilities import (timestamp_to_human,
                               timestamp_to_seconds,
                               seconds_to_timestamp)
 from . import helpers
-from joule.client import FilterModule
+from joule import FilterModule
 
 ARGS_DESC = """
 ---
@@ -107,7 +108,9 @@ class Sinefit(FilterModule):
             zc = outputs['zero_crossings']
         except KeyError as e:
             raise helpers.FilterError("missing stream %s" % e)
-    
+
+        # cache the sinefit pipe
+        zc.enable_cache(60) # 1 out per second
         rows_processed = 0
         f_expected = parsed_args.frequency
         a_min = parsed_args.min_amp
@@ -116,8 +119,11 @@ class Sinefit(FilterModule):
         # 1 indexed but ts is col 0 so this is correct
         column = parsed_args.v_index
 
-        while(True):
-            data = await iv.read(flatten=True)
+        while True:
+            try:
+                data = await iv.read(flatten=True)
+            except EmptyPipe:
+                break
             await asyncio.sleep(0.1)
             rows = data.shape[0]
 
@@ -136,6 +142,9 @@ class Sinefit(FilterModule):
 
             # If we don't have enough data, don't bother processing it
             if rows < N:
+                # stop if the pipeline is closed
+                if iv.closed:
+                    break
                 continue
             warn = helpers.SuppressibleWarning(3, 1000)
 
@@ -213,6 +222,7 @@ class Sinefit(FilterModule):
             rows_processed += start
             if(nrows > 0 and rows_processed >= nrows):
                 break
+        await zc.close()
 
 
 def main():
